Contributing
============
If you would like to contribute cheetsheets or program functionality, please
fork this repository, make your changes, and submit a pull request against the
`master` branch.


## Python standards ##
Python code should conform to [PEP 8][].


## Cheatsheet Format ##
Please pattern your cheatsheets after the following:

```sh
# To extract an uncompressed archive:
tar -xvf /path/to/foo.tar

# To create an uncompressed archive:
tar -cvf /path/to/foo.tar /path/to/foo/

# To extract a .gz archive:
tar -xzvf /path/to/foo.tgz
```

If you are submitting a cheatsheet that contains side-by-side columns of text,
please align the columns using spaces rather than tabs.

[PEP 8]: http://legacy.python.org/dev/peps/pep-0008/ 
